#[non_exhaustive]pub enum ComponentResolveError {
Missing {
component: ComponentId,
},
Failed {
component: ComponentId,
reason: String,
},
}Expand description
Typed failures returned by a ComponentResolver.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Missing
The requested component is not available to the resolver.
Fields

component: ComponentIdIdentity of the missing component.
Failed
The resolver could not read or construct the requested component.
Fields

component: ComponentIdIdentity of the component that could not be resolved.