pub enum BzzError {
TooShort,
InvalidBlockSize,
InvalidBwtIndex,
ZpError,
MissingMarker,
}Expand description
BZZ compression decoding errors.
Variants
TooShort
Input is too short to be a valid BZZ stream (fewer than 2 bytes).
InvalidBlockSize
The block size field in the BZZ stream is invalid or out of range.
InvalidBwtIndex
The BWT sort index embedded in the stream is out of range.
ZpError
The ZP arithmetic coder encountered an error.
MissingMarker
The BWT block did not contain an end-of-block marker.